@@ -6,7 +6,7 @@ class ActivityLog(GenericLog):
     csharp_class_name: str = 'com.lw.common.logging.messages.ActivityLog, com.lw.common.logging.messages'
 
     def __init__(self, origin, message, ip_address, additional_information, tags):
-        super(ActivityLog, self).__init__(self.class_name, origin, message, ip_address, additional_information, tags)
+        super().__init__(self.class_name, origin, message, ip_address, additional_information, tags)
 
     def as_legacy_dict(self):
         return {
