@@ -10,7 +10,7 @@ class ExceptionLog(GenericLog):
     inner_message: str
 
     def __init__(self, origin, source, stacktrace, message, inner_message, ip_address, additional_information, tags):
-        super(ExceptionLog, self).__init__(self.class_name, origin, message, ip_address, additional_information, tags)
+        super().__init__(self.class_name, origin, message, ip_address, additional_information, tags)
         self.source = source
         self.stacktrace = stacktrace
         self.inner_message = inner_message
